@@ -1,5 +1,5 @@
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -29,6 +29,7 @@
 
 from __future__ import print_function
 
+import errno
 import random
 import signal
 # pylint:disable=W0402
@@ -225,13 +226,14 @@ class SquidRunner(object):
         spool_path = _get_spool_temp_path(tempdir)
         squid_path = _get_squid_temp_path(tempdir)
         with open(self.config_file, 'w') as out_file:
-            out_file.write(template.safe_substitute(
-                              auth_file=self.auth_file,
-                              auth_process=self.auth_process,
-                              noauth_port_number=self.settings['noauth_port'],
-                              auth_port_number=self.settings['auth_port'],
-                              spool_temp=spool_path,
-                              squid_temp=squid_path))
+            out_file.write(
+                template.safe_substitute(
+                    auth_file=self.auth_file,
+                    auth_process=self.auth_process,
+                    noauth_port_number=self.settings['noauth_port'],
+                    auth_port_number=self.settings['auth_port'],
+                    spool_temp=spool_path,
+                    squid_temp=squid_path))
 
     def _generate_swap(self, config_file):
         """Generate the squid swap files."""
@@ -271,8 +273,8 @@ class SquidRunner(object):
             try:
                 #  Do not use stdout=PIPE or stderr=PIPE with this function.
                 subprocess.check_call([self.squid] + squid_args,
-                                       stdout=subprocess.PIPE,
-                                       stderr=subprocess.PIPE)
+                                      stdout=subprocess.PIPE,
+                                      stderr=subprocess.PIPE)
                 return True
             except subprocess.CalledProcessError:
                 message += '.'
@@ -304,7 +306,14 @@ class SquidRunner(object):
 
     def stop_service(self):
         """Stop our proxy,"""
-        kill_squid(self.squid_pid)
+        try:
+            kill_squid(self.squid_pid)
+        except OSError as err:
+            # If the process already died, ignore the error
+            if err.errno == errno.ESRCH:
+                pass
+            else:
+                raise
         delete_proxy_settings()
         self.running = False
         unlink(self.config_file)
